/*
   Library to offer additional compatibility with OpenBSD 2.7
*/

#ifndef _OBSD_H
#define _OBSD_H 

#define _MINIX_SOURCE 1

#include <stddef.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <minix/config.h>
#include <string.h>
#include <errno.h>
#include <sys/times.h>
#include <time.h>
#include <limits.h>
#include <fcntl.h>
#include <unistd.h>
#include <dirent.h>

#include <net/gen/in.h>
#include <net/gen/inet.h>
#include <net/gen/netdb.h>
#include <net/gen/socket.h>
#include <net/gen/tcp.h>
#include <net/gen/tcp_hdr.h>
#include <net/gen/tcp_io.h>
#include <net/hton.h>
#include <net/netlib.h>

#include <socket.h>

/* rlimit */

#define RLIMIT_CORE 4

typedef long rlim_t;

struct rlimit {
  rlim_t rlim_cur;
  rlim_t rlim_max;
};

#define ST_BLKSIZE 256

#define lstat stat

#define ITIMER_REAL 0
#define ITIMER_VIRTUAL 1
#define ITIMER_PROF 2

struct itimerval {
  struct timeval it_interval;
  struct timeval it_value;
};

#define seteuid(uid)   ((uid),0)

/* syslog */

/*
 * priorities/facilities are encoded into a single 32-bit quantity, where the
 * bottom 3 bits are the priority (0-7) and the top 28 bits are the facility
 * (0-big number).  Both the priorities and the facilities map roughly
 * one-to-one to strings in the syslogd(8) source code.  This mapping is
 * included in this file.
 *
 * priorities (these are ordered)
 */
#define LOG_EMERG 0 /* system is unusable */
#define LOG_ALERT 1 /* action must be taken immediately */
#define LOG_CRIT  2 /* critical conditions */
#define LOG_ERR   3 /* error conditions */
#define LOG_WARNING 4 /* warning conditions */
#define LOG_NOTICE  5 /* normal but significant condition */
#define LOG_INFO  6 /* informational */
#define LOG_DEBUG 7 /* debug-level messages */

/* facility codes */
#define LOG_KERN  (0<<3)  /* kernel messages */
#define LOG_USER  (1<<3)  /* random user-level messages */
#define LOG_MAIL  (2<<3)  /* mail system */
#define LOG_DAEMON  (3<<3)  /* system daemons */
#define LOG_AUTH  (4<<3)  /* security/authorization messages */
#define LOG_SYSLOG  (5<<3)  /* messages generated internally by syslogd */
#define LOG_LPR   (6<<3)  /* line printer subsystem */
#define LOG_NEWS  (7<<3)  /* network news subsystem */
#define LOG_UUCP  (8<<3)  /* UUCP subsystem */
#define LOG_CRON  (9<<3)  /* clock daemon */
#define LOG_AUTHPRIV  (10<<3) /* security/authorization messages (private) */
#define LOG_FTP   (11<<3) /* ftp daemon */

/* other codes through 15 reserved for system use */
#define LOG_LOCAL0  (16<<3) /* reserved for local use */
#define LOG_LOCAL1  (17<<3) /* reserved for local use */
#define LOG_LOCAL2  (18<<3) /* reserved for local use */
#define LOG_LOCAL3  (19<<3) /* reserved for local use */
#define LOG_LOCAL4  (20<<3) /* reserved for local use */
#define LOG_LOCAL5  (21<<3) /* reserved for local use */
#define LOG_LOCAL6  (22<<3) /* reserved for local use */
#define LOG_LOCAL7  (23<<3) /* reserved for local use */

#define LOG_NFACILITIES 24  /* current number of facilities */
#define LOG_FACMASK 0x03f8  /* mask to extract facility part */
/* facility of pri */
#define LOG_FAC(p)  (((p) & LOG_FACMASK) >> 3)

/*
 * Option flags for openlog.
 *
 * LOG_ODELAY no longer does anything.
 * LOG_NDELAY is the inverse of what it used to be.
 */
#define LOG_PID   0x01  /* log the pid with each message */
#define LOG_CONS  0x02  /* log on the console if errors in sending */
#define LOG_ODELAY  0x04  /* delay open until first syslog() (default) */
#define LOG_NDELAY  0x08  /* don't delay open */
#define LOG_NOWAIT  0x10  /* don't wait for console forks: DEPRECATED */
#define LOG_PERROR  0x20  /* log to stderr as well */

#define syslog(a, b, c)	fprintf(stderr, b, c)

/*
 * utmp.h
 */

#define UT_NAMESIZE 8
#define UT_LINESIZE 8
#define UT_HOSTSIZE 16

struct lastlog {
  time_t  ll_time;
  char  ll_line[UT_LINESIZE];
  char  ll_host[UT_HOSTSIZE];
};

/* reimplemented Minix crypt() to not collide with ssl crypt() */
char *sys_crypt(const char *key, const char *salt);

/* Not working functions, made to avoid compile errors */
#define   openlog(ident, opt, facility) ((void) 0)
#define   closelog()                    ((void) 0)
#define 	initgroups(name, gid) (0)
int setrlimit(void);
int setitimer(int a, const struct itimerval *b, struct itimerval *c);
int fchmod(int fd, mode_t mode);

#define MNX_DEBUG(x) x

#endif /* _OBSD_H */
